package com.example.ellegadodepintia.exploradoresDePintia

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import androidx.fragment.app.DialogFragment
import com.example.ellegadodepintia.R
import com.example.ellegadodepintia.exploradoresDePintia.model.GameState
import com.example.ellegadodepintia.exploradoresDePintia.model.Atributo
import com.example.ellegadodepintia.exploradoresDePintia.model.Jugador
import com.example.ellegadodepintia.exploradoresDePintia.model.LayoutUtils
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.Objeto
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.ObjetoConsumible
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.ObjetoDeValor
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.ObjetoEquipable
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.ObjetoUtilidad
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.efectoObjeto.EfectoObjetoCura

class ModalDetallesFragment : DialogFragment() {
    lateinit var objeto: Objeto
    var parentView: View? = null
    private var jugadorObserver: ((Jugador) -> Unit)? = null


    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        return inflater.inflate(R.layout.modal_detalles, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        jugadorObserver = { LayoutUtils.actualizarInventarioUI(parentView!!,parentFragmentManager) }
        GameState.jugador.addObserver(jugadorObserver!!)

        val params = dialog?.window?.attributes
        if (params != null) {
            params.width = (resources.displayMetrics.widthPixels * 0.90).toInt()
            params.height = ViewGroup.LayoutParams.WRAP_CONTENT
            dialog?.window?.attributes = params
        }

        val botonUsar: Button = view.findViewById(R.id.botonUsar)
        val botonDestruir: Button = view.findViewById(R.id.botonDestruir)

        if(GameState.jugador.equipables.contains(objeto)){
            "Desequipar".also { botonUsar.text = it }
            botonDestruir.visibility = View.GONE
            val layoutParams = LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.MATCH_PARENT,
                LinearLayout.LayoutParams.WRAP_CONTENT
            ).apply {
                marginEnd = 0
                width = (165 * GameState.context!!.resources.displayMetrics.density).toInt()
                height = (50 * GameState.context!!.resources.displayMetrics.density).toInt()
            }

            botonUsar.layoutParams = layoutParams

        }else if (objeto is ObjetoEquipable) {
            "Equipar".also { botonUsar.text = it }
        } else if (objeto is ObjetoDeValor || objeto is ObjetoUtilidad){
            val parent = botonUsar.parent as ViewGroup
            parent.removeView(botonUsar)
        }

        botonUsar.setOnClickListener {
            if(GameState.jugador.equipables.contains(objeto)){
                desequipar()
            }else{
                usar()
            }
        }

        botonDestruir.setOnClickListener {
            destruir()
        }

        view.findViewById<ImageView>(R.id.imagenObjeto).setImageResource(objeto.imagen)
        view.findViewById<TextView>(R.id.nombreObjeto).text = objeto.nombre
        view.findViewById<TextView>(R.id.descripcionObjeto).text = objeto.descripcion


    }

    private fun usar() {
        val esConsumibleConEfectoDeCura = objeto is ObjetoConsumible && (objeto as ObjetoConsumible).efecto is EfectoObjetoCura

        if (esConsumibleConEfectoDeCura) {
            if (GameState.jugador.atributos[Atributo.Vida]!! == GameState.jugador.vidaMax) {
                val mensaje = "Tu salud ya está al máximo. No necesitas usar ${objeto.nombre}."
                view?.findViewById<TextView>(R.id.textoResultadoUso)?.text = mensaje
                return
            }
        }
        if(GameState.jugador.equipables.size == 3){
            val mensaje = "No te queda espacio para equipar nada más"
            view?.findViewById<TextView>(R.id.textoResultadoUso)?.text = mensaje
        }else{
            objeto.usar()
            destruir()
        }

    }

    private fun destruir(){
        GameState.jugador.destruirObjeto(objeto)
        dismiss()
    }

    private fun desequipar(){
        if(GameState.jugador.inventario.size == 9){
            val mensaje = "Tienes el inventario lleno"
            view?.findViewById<TextView>(R.id.textoResultadoUso)?.text = mensaje
        }else{
            val objetoEquipado = objeto as ObjetoEquipable
            objetoEquipado.desequipar()
            dismiss()
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        jugadorObserver?.let { GameState.jugador.removeObserver(it) }
        jugadorObserver = null
    }



}
