    package com.example.ellegadodepintia.repositorios

import com.example.ellegadodepintia.R
import com.example.ellegadodepintia.exploradoresDePintia.model.Atributo
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.*
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.efectoObjeto.EfectoEquipableAumento
import com.example.ellegadodepintia.exploradoresDePintia.model.objeto.efectoObjeto.EfectoObjetoCura

object RepositorioObjetos {
    private val objetos: Map<String, Objeto> by lazy {
        listOf(
            ObjetoDeValor(
                nombre = "Vasito de barro cocido",
                descripcion = "Objeto de gran valor. Se convierte en 20 monedas si consigues completar la partida.",
                coste = 20,
                imagen = R.drawable.asi_exploradores_vasito
            ),
            ObjetoDeValor(
                nombre = "Jabonera de cerámica",
                descripcion = "Objeto de gran valor. Se convierte en 20 monedas si consigues completar la partida.",
                coste = 20,
                imagen = R.drawable.asi_exploradores_jabonera
            ),
            ObjetoDeValor(
                nombre = "Copa negra con inscripciones",
                descripcion = "Objeto de gran valor. Se convierte en 20 monedas si consigues completar la partida.",
                coste = 20,
                imagen = R.drawable.asi_minijuego_3_copa_negra_brunida
            ),
            ObjetoDeValor(
                nombre = "Tapadera de cerámica zoomorfa",
                descripcion = "Objeto de gran valor. Se convierte en 20 monedas si consigues completar la partida.",
                coste = 20,
                imagen = R.drawable.asi_minijuego_3_tapadera_zoomorfo
            ),
            ObjetoEquipable(
                nombre = "Espada de Hierro",
                descripcion = "Una espada de hierro sencilla y confiable perfecta para un aventurero novato. Otorga 1 de daño extra",
                efecto = EfectoEquipableAumento(1, Atributo.Ataque),
                imagen = R.drawable.asi_objeto_espadadefault
            ),
            ObjetoConsumible(
                nombre = "Elixir Menor de la Necrópolis",
                descripcion = "Un frasco pequeño con un líquido granate y brillante, que destella con un resplandor profundo, capaz de restaurar 3 puntos de vida al instante.",
                efecto = EfectoObjetoCura(3),
                imagen = R.drawable.asi_objeto_pocima_vida_5
            ),
            ObjetoConsumible(
                nombre = "Elixir Mediano de la Necrópolis",
                descripcion = "Un frasco robusto con un líquido amarillo brillante, que resplandece como el sol al mediodía, capaz de restaurar 5 puntos de vida al instante.",
                efecto = EfectoObjetoCura(5),
                imagen = R.drawable.asi_objeto_pocima_vida_10
            ),
            ObjetoConsumible(
                nombre = "Elixir Supremo de la Necrópolis",
                descripcion = "Frasco supremo forjado con los secretos de los vacceos, restaura toda tu vitalidad al instante, ¡la poción de cura más poderosa de Pintia!",
                efecto = EfectoObjetoCura(999),
                imagen = R.drawable.asi_objeto_pocima_vida_all
            ),
            ObjetoEquipable(
                nombre = "Escudo Caetrae",
                descripcion = "La caetrae es un escudo redondo vacceo, forjado para la defensa en combate, que aumenta tu vida máxima en 10 puntos.",
                efecto = EfectoEquipableAumento(10, Atributo.Vida),
                imagen = R.drawable.asi_objeto_escudo
            ),
            ObjetoEquipable(
                nombre = "Casco Ceremonial",
                descripcion = "Casco ceremonial de oro de los vacceos decorado con intrincados patrones que simboliza el estatus social. Aumenta tu vida máxima en 8 puntos",
                efecto = EfectoEquipableAumento(8, Atributo.Vida),
                imagen = R.drawable.asi_objeto_casco
            ),
            ObjetoUtilidad(
                nombre = "Pico Vacceo",
                descripcion = "Un pico viejo y oscuro con dibujos extraños que parecen brillar cerca de las piedras, como si estuviera esperando que lo uses para algo importante.",
                imagen = R.drawable.asi_objeto_pico
            ),
            ObjetoUtilidad(
                nombre = "Ticket",
                descripcion = "Representa una invitación a un evento relacionado con la cultura vaccea, como una feria arqueológica o un festival cultural",
                imagen = R.drawable.asi_objeto_ticket
            )
        ).associateBy { it.nombre }
    }

    fun obtenerObjetoPorNombre(nombre: String): Objeto? {
        return objetos[nombre]
    }

    fun obtenerObjetosAleatoriosTienda(cantidad: Int): ArrayList<String> {
        val consumibles = objetos.values.filter { it is ObjetoConsumible || it is ObjetoUtilidad }
        return ArrayList<String>().apply {
            repeat(cantidad) {
                add((consumibles.random()).nombre)
            }
        }
    }

    fun obtenerObjetosAleatoriosArmeria(cantidad: Int): ArrayList<String> {
        val equipables = objetos.values.filterIsInstance<ObjetoEquipable>()
        return ArrayList<String>().apply {
            repeat(cantidad) {
                println((equipables.random()).nombre)
                add((equipables.random()).nombre)
            }
        }
    }

    fun convertirNombresAObjetos(nombres: List<String>): List<Objeto?> {
        return nombres.map { nombre ->
            obtenerObjetoPorNombre(nombre)
        }
    }
}